@@ -1,13 +1,15 @@
 import json
+from flask_cors import CORS
 from flask import Flask, request
 from rainbond_python.parameter import Parameter
 from rainbond_python.error_handler import error_handler
 
 app = Flask(__name__)
+CORS(app, supports_credentials=True)
 error_handler(app)
 
 
-@app.route('/demo/1.0/demo', methods=['GET', 'POST', 'PUT', 'DELETE'])
+@app.route('/api/1.0/demo', methods=['GET', 'POST', 'PUT', 'DELETE'])
 def api_demo():
     parameter = Parameter(request)
 
